==> ejc-ztpczr-impl-3.0.0-20230607.033342-18-sources.jar: com/ejianc/business/ztpczr/service/impl/SystemServiceImpl.java <==
package com.ejianc.business.ztpczr.service.impl;

import com.ejianc.business.ztpczr.mapper.SystemMapper;
import com.ejianc.business.ztpczr.service.ISystemService;
import com.ejianc.business.ztpczr.bean.DcFileTypeQuery;
import com.ejianc.business.ztpczr.bean.SystemEntity;
import com.ejianc.business.ztpczr.bean.SystemRtEntity;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * CVAR
 * 
 * @author generator
 * 
 */

@Service("systemServiceImpl")
public class SystemServiceImpl extends BaseServiceImpl<SystemMapper, SystemRtEntity> implements ISystemService {


    @Autowired
    private SystemMapper systemMapper;

    @Autowired
    private SessionManager sessionManager;

    @Override
    public List<SystemRtEntity> selectByCode(List<SystemEntity> systemEntities){
        return systemMapper.selectByCode(systemEntities);
    }

    @Override
    public List<SystemRtEntity> selectDictByCode(String code) {
        return systemMapper.selectDictByCode(code);
    }

    @Override
    public List<SystemEntity> selectByTableName(String billType) {
        return systemMapper.selectByTableName(billType);
    }

    @Override
    public List<DcFileTypeQuery> dcFileTypeQuery(Map<String,Object> params) {
        return systemMapper.dcFileTypeQuery(params);
    }


}

==> ejc-ztpczr-impl-3.0.0-20230608.072858-21-sources.jar: com/ejianc/business/ztpczr/service/impl/SystemServiceImpl.java <==
package com.ejianc.business.ztpczr.service.impl;

import com.ejianc.business.ztpczr.bean.RefProjectPoolEntity;
import com.ejianc.business.ztpczr.mapper.SystemMapper;
import com.ejianc.business.ztpczr.service.ISystemService;
import com.ejianc.business.ztpczr.bean.DcFileTypeQuery;
import com.ejianc.business.ztpczr.bean.SystemEntity;
import com.ejianc.business.ztpczr.bean.SystemRtEntity;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * CVAR
 * 
 * @author generator
 * 
 */

@Service("systemServiceImpl")
public class SystemServiceImpl extends BaseServiceImpl<SystemMapper, SystemRtEntity> implements ISystemService {


    @Autowired
    private SystemMapper systemMapper;

    @Autowired
    private SessionManager sessionManager;

    @Override
    public List<SystemRtEntity> selectByCode(List<SystemEntity> systemEntities){
        return systemMapper.selectByCode(systemEntities);
    }

    @Override
    public List<RefProjectPoolEntity> refProjectPool() {
        return systemMapper.refProjectPool();
    }

    @Override
    public List<SystemRtEntity> selectDictByCode(String code) {
        return systemMapper.selectDictByCode(code);
    }

    @Override
    public List<SystemEntity> selectByTableName(String billType) {
        return systemMapper.selectByTableName(billType);
    }

    @Override
    public List<DcFileTypeQuery> dcFileTypeQuery(Map<String,Object> params) {
        return systemMapper.dcFileTypeQuery(params);
    }


}
